import java.io.*;
import store.*;
/**
* This class contains the information needed to identify a
* user account on a particular host.
*/
public class UserAccount implements Storable {
	/**
	* Construct a new UserAccount object with empty
	* Strings for all of the fields.
	*/
	public UserAccount() {
		this("","","","");
	}
	/**
	* Construct a new UserAccount object using the 
	* supplied strings.  If any of the parameters are
	* null, an empty String will be used instead.
	* @param label the display name of this account
	* @param host the host computer for which this account
	* name is defined
	* @param username the name associated with this user
	* @param password the password for this account
	*/
	public UserAccount(String label, String host, 
	String username, String password) {
		this.label = (label==null) ? "" : label;
		this.host = (host==null) ? "" : host;
		this.username = (username==null) ? "" : username;
		this.password = (password==null) ? "" : password;
	}
	/**
	* Return the label for this object.
	* @return the label String 
	*/
	public String getLabel() {
		return label;
	}
	/**
	* Return the host for this object.
	* @return the host String 
	*/
	public String getHost() {
		return host;
	}
	/**
	* Return the username for this object.
	* @return the username String 
	*/
	public String getUsername() {
		return username;
	}
	/**
	* Return the password for this object.
	* @return the password String 
	*/
	public String getPassword() {
		return password;
	}
	/**
	* Set the label for this object.
	* @param label the label String 
	*/
	public void setLabel(String label) {
		this.label = (label==null) ? "" : label;
	}
	/**
	* Set the host for this object.
	* @param host the host String 
	*/
	public void setHost(String host) {
		this.host = (host==null) ? "" : host;
	}
	/**
	* Set the username for this object.
	* @param username the username String 
	*/
	public void setUsername(String username) {
		this.username = (username==null) ? "" : username;
	}
	/**
	* Set the password for this object.
	* @param password the password String 
	*/
	public void setPassword(String password) {
		this.password = (password==null) ? "" : password;
	}
	/**
	* Write the data for this object out onto the given
	* DataOutputStream.
	* @param os the DataOutputStream on which to write the data fields
	* for this object.
	* @throws IOException if an error occurs while writing
	*/
	public void writeFields(DataOutputStream os) throws IOException {
		os.writeUTF(label);
		os.writeUTF(host);
		os.writeUTF(username);
		os.writeUTF(password);
	}
	/**
	* Read the data for this object from the given
	* DataInputStream.
	* @param is the DataInputStream from which to read the data fields
	* for this object.
	* @throws IOException if an error occurs while reading
	*/
	public void readFields(DataInputStream is) throws IOException {
		label = is.readUTF();
		host = is.readUTF();
		username = is.readUTF();
		password = is.readUTF();
	}
	/**
	* Compare two UserAccount objects for order. 
	* @param a the first object in the comparison
	* @param b the second object in the comparison
	* @return -1, 0, or +1 as the first argument is less than,
	* equal to, or greater than the second.
	*/
	public static int compare(UserAccount a, UserAccount b) {
		int k = a.getLabel().compareTo(b.getLabel());
		if (k < 0) {
			return -1;
		} else if (k > 0) {
			return +1;
		} else {
			k = a.getHost().compareTo(b.getHost());
			if (k < 0) {
				return -1;
			} else if (k > 0) {
				return +1;
			} else {
				k = a.getUsername().compareTo(b.getUsername());
				if (k < 0) {
					return -1;
				} else if (k > 0) {
					return +1;
				} else {
					k = a.getPassword().compareTo(b.getPassword());
					if (k < 0) {
						return -1;
					} else if (k > 0) {
						return +1;
					} else {
						return 0;
					}
				}
			}
		}
	}

	//-----------------------------------------------------------------------
	
	private String label;
	private String host;
	private String username;
	private String password;
	
}

